@@ -51,7 +51,7 @@ show_data_sources (GnomeDbDataSourceSelector *selector, const gchar *name)
 	gtk_option_menu_remove_menu (GTK_OPTION_MENU (selector));
 
 	/* load data sources */
-	dsn_list = gda_config_get_data_source_list ();
+	dsn_list = gnome_db_config_get_data_source_list ();
 	for (l = dsn_list; l != NULL; l = l->next) {
 		GdaDataSourceInfo *dsn_info = (GdaDataSourceInfo *) l->data;
 
@@ -65,7 +65,7 @@ show_data_sources (GnomeDbDataSourceSelector *selector, const gchar *name)
 		gnome_db_option_menu_add_item (GTK_OPTION_MENU (selector), dsn_info->name);
 	}
 
-	gda_config_free_data_source_list (dsn_list);
+	gnome_db_config_free_data_source_list (dsn_list);
 }
 
 /*
