@@ -38,6 +38,8 @@ typedef struct _GnomeDbGrid        GnomeDbGrid;
 typedef struct _GnomeDbGridClass   GnomeDbGridClass;
 typedef struct _GnomeDbGridPrivate GnomeDbGridPrivate;
 
+typedef void (* GnomeDbGridForeachFunc) (GnomeDbGrid *grid, gint row, gpointer user_data);
+
 struct _GnomeDbGrid {
 	GtkVBox parent;
 	GnomeDbGridPrivate *priv;
@@ -57,6 +59,9 @@ GtkWidget       *gnome_db_grid_new_with_model (GdaDataModel *model);
 GdaDataModel    *gnome_db_grid_get_model (GnomeDbGrid *grid);
 void             gnome_db_grid_set_model (GnomeDbGrid *grid, GdaDataModel *model);
 GList           *gnome_db_grid_get_selection (GnomeDbGrid *grid);
+void             gnome_db_grid_foreach_selected (GnomeDbGrid *grid,
+						 GnomeDbGridForeachFunc foreach_func,
+						 gpointer user_data);
 void             gnome_db_grid_select_all (GnomeDbGrid *grid);
 void             gnome_db_grid_unselect_all (GnomeDbGrid *grid);
 GtkSelectionMode gnome_db_grid_get_selection_mode (GnomeDbGrid *grid);
